==> net.java.html.lib-0.2-sources.jar: net/java/html/lib/DataView.java <==
package net.java.html.lib;
public class DataView extends net.java.html.lib.Objs {
  protected DataView(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<DataView> {
    $Constructor() {
      super(DataView.class);
    }
    @Override
    public DataView create(java.lang.Object obj) {
      return obj == null ? null : new DataView(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static DataView $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  public net.java.html.lib.Objs.Property<ArrayBuffer> buffer = net.java.html.lib.Objs.Property.create(this, net.java.html.lib.ArrayBuffer.class, "buffer");
  public ArrayBuffer buffer() { return buffer.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Number> byteLength = net.java.html.lib.Objs.Property.create(this, java.lang.Number.class, "byteLength");
  public java.lang.Number byteLength() { return byteLength.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Number> byteOffset = net.java.html.lib.Objs.Property.create(this, java.lang.Number.class, "byteOffset");
  public java.lang.Number byteOffset() { return byteOffset.get(); }
  /**
  * Gets the Float32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getFloat32(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getFloat32$19($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Float32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getFloat32(double byteOffset) {
    return $Typings$.getFloat32$20($js(this), byteOffset);
  }
  /**
  * Gets the Float64 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getFloat64(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getFloat64$21($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Float64 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getFloat64(double byteOffset) {
    return $Typings$.getFloat64$22($js(this), byteOffset);
  }
  /**
  * Gets the Int16 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt16(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getInt16$23($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Int16 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt16(double byteOffset) {
    return $Typings$.getInt16$24($js(this), byteOffset);
  }
  /**
  * Gets the Int32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt32(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getInt32$25($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Int32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt32(double byteOffset) {
    return $Typings$.getInt32$26($js(this), byteOffset);
  }
  /**
  * Gets the Int8 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt8(double byteOffset) {
    return $Typings$.getInt8$27($js(this), byteOffset);
  }
  /**
  * Gets the Uint16 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint16(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getUint16$28($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Uint16 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint16(double byteOffset) {
    return $Typings$.getUint16$29($js(this), byteOffset);
  }
  /**
  * Gets the Uint32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint32(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getUint32$30($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Uint32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint32(double byteOffset) {
    return $Typings$.getUint32$31($js(this), byteOffset);
  }
  /**
  * Gets the Uint8 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint8(double byteOffset) {
    return $Typings$.getUint8$32($js(this), byteOffset);
  }
  /**
  * Stores an Float32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setFloat32(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setFloat32$33($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Float32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setFloat32(double byteOffset, double value) {
    $Typings$.setFloat32$34($js(this), byteOffset, value);
  }
  /**
  * Stores an Float64 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setFloat64(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setFloat64$35($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Float64 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setFloat64(double byteOffset, double value) {
    $Typings$.setFloat64$36($js(this), byteOffset, value);
  }
  /**
  * Stores an Int16 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setInt16(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setInt16$37($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Int16 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setInt16(double byteOffset, double value) {
    $Typings$.setInt16$38($js(this), byteOffset, value);
  }
  /**
  * Stores an Int32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setInt32(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setInt32$39($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Int32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setInt32(double byteOffset, double value) {
    $Typings$.setInt32$40($js(this), byteOffset, value);
  }
  /**
  * Stores an Int8 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  */
  public void setInt8(double byteOffset, double value) {
    $Typings$.setInt8$41($js(this), byteOffset, value);
  }
  /**
  * Stores an Uint16 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setUint16(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setUint16$42($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Uint16 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setUint16(double byteOffset, double value) {
    $Typings$.setUint16$43($js(this), byteOffset, value);
  }
  /**
  * Stores an Uint32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setUint32(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setUint32$44($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Uint32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setUint32(double byteOffset, double value) {
    $Typings$.setUint32$45($js(this), byteOffset, value);
  }
  /**
  * Stores an Uint8 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  */
  public void setUint8(double byteOffset, double value) {
    $Typings$.setUint8$46($js(this), byteOffset, value);
  }
  // constructor DataViewConstructor
  public DataView(ArrayBuffer buffer, double byteOffset, double byteLength) {
    this(DataView.$AS, $Typings$.new$47(/* FirstTypeNode*/$js(buffer), byteOffset, byteLength));
  }
  public DataView(ArrayBuffer buffer) {
    this(DataView.$AS, $Typings$.new$48(/* FirstTypeNode*/$js(buffer)));
  }
  public DataView(ArrayBuffer buffer, double byteOffset) {
    this(DataView.$AS, $Typings$.new$49(/* FirstTypeNode*/$js(buffer), byteOffset));
  }
}

==> net.java.html.lib-0.5-sources.jar: net/java/html/lib/DataView.java <==
package net.java.html.lib;
public class DataView extends net.java.html.lib.Objs {
  protected DataView(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<DataView> {
    $Constructor() {
      super(DataView.class);
    }
    @Override
    public DataView create(java.lang.Object obj) {
      return obj == null ? null : new DataView(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static DataView $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  public net.java.html.lib.Objs.Property<net.java.html.lib.ArrayBuffer> buffer = net.java.html.lib.Objs.Property.create(this, net.java.html.lib.ArrayBuffer.class, "buffer");
  public net.java.html.lib.ArrayBuffer buffer() { return buffer.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Number> byteLength = net.java.html.lib.Objs.Property.create(this, java.lang.Number.class, "byteLength");
  public java.lang.Number byteLength() { return byteLength.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Number> byteOffset = net.java.html.lib.Objs.Property.create(this, java.lang.Number.class, "byteOffset");
  public java.lang.Number byteOffset() { return byteOffset.get(); }
  /**
  * Gets the Float32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getFloat32(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getFloat32$19($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Float32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getFloat32(double byteOffset) {
    return $Typings$.getFloat32$20($js(this), byteOffset);
  }
  /**
  * Gets the Float64 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getFloat64(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getFloat64$21($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Float64 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getFloat64(double byteOffset) {
    return $Typings$.getFloat64$22($js(this), byteOffset);
  }
  /**
  * Gets the Int16 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt16(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getInt16$23($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Int16 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt16(double byteOffset) {
    return $Typings$.getInt16$24($js(this), byteOffset);
  }
  /**
  * Gets the Int32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt32(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getInt32$25($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Int32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt32(double byteOffset) {
    return $Typings$.getInt32$26($js(this), byteOffset);
  }
  /**
  * Gets the Int8 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getInt8(double byteOffset) {
    return $Typings$.getInt8$27($js(this), byteOffset);
  }
  /**
  * Gets the Uint16 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint16(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getUint16$28($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Uint16 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint16(double byteOffset) {
    return $Typings$.getUint16$29($js(this), byteOffset);
  }
  /**
  * Gets the Uint32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint32(double byteOffset, java.lang.Boolean littleEndian) {
    return $Typings$.getUint32$30($js(this), byteOffset, littleEndian);
  }
  /**
  * Gets the Uint32 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint32(double byteOffset) {
    return $Typings$.getUint32$31($js(this), byteOffset);
  }
  /**
  * Gets the Uint8 value at the specified byte offset from the start of the view. There is
  * no alignment constraint; multi-byte values may be fetched from any offset.
  * @param byteOffset The place in the buffer at which the value should be retrieved.
  */
  public double getUint8(double byteOffset) {
    return $Typings$.getUint8$32($js(this), byteOffset);
  }
  /**
  * Stores an Float32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setFloat32(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setFloat32$33($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Float32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setFloat32(double byteOffset, double value) {
    $Typings$.setFloat32$34($js(this), byteOffset, value);
  }
  /**
  * Stores an Float64 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setFloat64(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setFloat64$35($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Float64 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setFloat64(double byteOffset, double value) {
    $Typings$.setFloat64$36($js(this), byteOffset, value);
  }
  /**
  * Stores an Int16 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setInt16(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setInt16$37($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Int16 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setInt16(double byteOffset, double value) {
    $Typings$.setInt16$38($js(this), byteOffset, value);
  }
  /**
  * Stores an Int32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setInt32(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setInt32$39($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Int32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setInt32(double byteOffset, double value) {
    $Typings$.setInt32$40($js(this), byteOffset, value);
  }
  /**
  * Stores an Int8 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  */
  public void setInt8(double byteOffset, double value) {
    $Typings$.setInt8$41($js(this), byteOffset, value);
  }
  /**
  * Stores an Uint16 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setUint16(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setUint16$42($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Uint16 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setUint16(double byteOffset, double value) {
    $Typings$.setUint16$43($js(this), byteOffset, value);
  }
  /**
  * Stores an Uint32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setUint32(double byteOffset, double value, java.lang.Boolean littleEndian) {
    $Typings$.setUint32$44($js(this), byteOffset, value, littleEndian);
  }
  /**
  * Stores an Uint32 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  * @param littleEndian If false or undefined, a big-endian value should be written,
  * otherwise a little-endian value should be written.
  */
  public void setUint32(double byteOffset, double value) {
    $Typings$.setUint32$45($js(this), byteOffset, value);
  }
  /**
  * Stores an Uint8 value at the specified byte offset from the start of the view.
  * @param byteOffset The place in the buffer at which the value should be set.
  * @param value The value to set.
  */
  public void setUint8(double byteOffset, double value) {
    $Typings$.setUint8$46($js(this), byteOffset, value);
  }
  // constructor DataViewConstructor
  public DataView(net.java.html.lib.ArrayBuffer buffer, double byteOffset, double byteLength) {
    this(DataView.$AS, $Typings$.new$47(/* FirstTypeNode*/$js(buffer), byteOffset, byteLength));
  }
  public DataView(net.java.html.lib.ArrayBuffer buffer) {
    this(DataView.$AS, $Typings$.new$48(/* FirstTypeNode*/$js(buffer)));
  }
  public DataView(net.java.html.lib.ArrayBuffer buffer, double byteOffset) {
    this(DataView.$AS, $Typings$.new$49(/* FirstTypeNode*/$js(buffer), byteOffset));
  }
}
